@@ -77,7 +77,7 @@ class DAppClient:
         try:
             resp = await resp.json()
         except Exception:  # TODO: catch correct exceptions
-            raise DAppWrongResult(ErrorMsg(resp.reason, resp.status))
+            raise DAppWrongResult([ErrorMsg(message=resp.reason, code=resp.status)])
         
         if "errors" in resp and resp['errors']:
             errors = [ErrorMsg.parse_obj(error) for error in resp['errors']]
